@@ -284,9 +284,9 @@ class NDUncertainty(metaclass=ABCMeta):
                     unit_from_data.to(self.unit)
                 except UnitConversionError:
                     raise UnitConversionError(
-                        "Unit {} of uncertainty "
-                        "incompatible with unit {} of "
-                        "data".format(self.unit, parent_unit)
+                        f"Unit {self.unit} of uncertainty "
+                        f"incompatible with unit {parent_unit} of "
+                        "data"
                     )
 
     @abstractmethod
@@ -305,7 +305,7 @@ class NDUncertainty(metaclass=ABCMeta):
         except AttributeError:
             # In case it wasn't possible to use array2string
             body = str(self.array)
-        return "".join([prefix, body, ")"])
+        return f"{prefix}{body})"
 
     def __getstate__(self):
         # Because of the weak reference the class wouldn't be picklable.
